# Clired --- Command-line Redescription Mining

clired is a command-line tool for redescription mining.


### Installation

#### Dependencies
`python-clired` requires several other Python utilities, including Numpy, Scipy, Scikit-learn.

* python-dateutil (>= 2.8.1)
* shapely (>= 1.7.0)
* numpy (>= 1.13.0)
* scipy (>= 0.19.0)
* scikit-learn (>= 0.19.0)

#### PIP
with pip, installation should be as easy as running 
`pip install python-clired`

this should provide `exec_clired` to run the command-line redescription mining algorithms

### More information
See http://cs.uef.fi/siren/

### License
Clired is licensed under Apache License v2.0. See attached file "LICENSE".

(c) Esther Galbrun and Pauli Miettinen, 2012
